@@ -30,7 +30,10 @@ impl<'l, T: 'l> BetterIteratorExt<'l, T> for &'l [T]
 {
 	fn iter2(self) -> BetterIterator<'l, T>
 	{
-		BetterIterator { idx: 0, slice: self }
+		BetterIterator {
+			idx: 0,
+			slice: self,
+		}
 	}
 }
 
@@ -83,7 +86,7 @@ impl Common
 	{
 		if !self.no_show
 		{
-			fg.show();
+			fg.show().unwrap();
 		}
 		fg.echo_to_file(filename);
 	}
