@@ -22,16 +22,18 @@ fn main()
 		let ax = fg.axes2d().set_y_range(Fix(-1.0), Fix(1.0));
 		ax.lines(
 			x.iter(),
-			x.iter().map(|&x| (x + t as f32 * 0.1 * 2. * f32::consts::PI).sin()),
+			x.iter()
+				.map(|&x| (x + t as f32 * 0.1 * 2. * f32::consts::PI).sin()),
 			&[Color("blue")],
 		);
 		ax.lines(
 			x.iter(),
-			x.iter().map(|&x| (x + t as f32 * 0.1 * 2. * f32::consts::PI).cos()),
+			x.iter()
+				.map(|&x| (x + t as f32 * 0.1 * 2. * f32::consts::PI).cos()),
 			&[Color("red")],
 		);
 		t += 0.1;
 	}
 	fg.echo_to_file("fg.gif.gnuplot");
-	fg.show();
+	fg.show().unwrap();
 }
