@@ -13,6 +13,7 @@ use crate::datatype::*;
 use crate::options::*;
 use crate::util::OneWayOwned;
 use crate::writer::*;
+use std::borrow::Borrow;
 use std::io::Write;
 
 pub struct PlotElement
@@ -28,7 +29,9 @@ pub struct PlotElement
 
 impl PlotElement
 {
-	pub fn new_plot2<T1, X1, T2, X2>(plot_type: PlotType, x1: X1, x2: X2, options: Vec<PlotOption<String>>) -> PlotElement
+	pub fn new_plot2<T1, X1, T2, X2>(
+		plot_type: PlotType, x1: X1, x2: X2, options: Vec<PlotOption<String>>,
+	) -> PlotElement
 	where
 		T1: DataType,
 		X1: IntoIterator<Item = T1>,
@@ -56,7 +59,9 @@ impl PlotElement
 		}
 	}
 
-	pub fn new_plot3<T1, X1, T2, X2, T3, X3>(plot_type: PlotType, x1: X1, x2: X2, x3: X3, options: Vec<PlotOption<String>>) -> PlotElement
+	pub fn new_plot3<T1, X1, T2, X2, T3, X3>(
+		plot_type: PlotType, x1: X1, x2: X2, x3: X3, options: Vec<PlotOption<String>>,
+	) -> PlotElement
 	where
 		T1: DataType,
 		X1: IntoIterator<Item = T1>,
@@ -88,7 +93,8 @@ impl PlotElement
 	}
 
 	pub fn new_plot5<T1, X1, T2, X2, T3, X3, T4, X4, T5, X5>(
-		plot_type: PlotType, x1: X1, x2: X2, x3: X3, x4: X4, x5: X5, options: Vec<PlotOption<String>>,
+		plot_type: PlotType, x1: X1, x2: X2, x3: X3, x4: X4, x5: X5,
+		options: Vec<PlotOption<String>>,
 	) -> PlotElement
 	where
 		T1: DataType,
@@ -105,7 +111,8 @@ impl PlotElement
 		let mut num_rows = 0;
 		let mut data = vec![];
 		// TODO: Reserve.
-		for ((((x1, x2), x3), x4), x5) in x1.into_iter()
+		for ((((x1, x2), x3), x4), x5) in x1
+			.into_iter()
 			.zip(x2.into_iter())
 			.zip(x3.into_iter())
 			.zip(x4.into_iter())
@@ -131,7 +138,8 @@ impl PlotElement
 	}
 
 	pub fn new_plot6<T1, X1, T2, X2, T3, X3, T4, X4, T5, X5, T6, X6>(
-		plot_type: PlotType, x1: X1, x2: X2, x3: X3, x4: X4, x5: X5, x6: X6, options: Vec<PlotOption<String>>,
+		plot_type: PlotType, x1: X1, x2: X2, x3: X3, x4: X4, x5: X5, x6: X6,
+		options: Vec<PlotOption<String>>,
 	) -> PlotElement
 	where
 		T1: DataType,
@@ -150,7 +158,8 @@ impl PlotElement
 		let mut num_rows = 0;
 		let mut data = vec![];
 		// TODO: Reserve.
-		for (((((x1, x2), x3), x4), x5), x6) in x1.into_iter()
+		for (((((x1, x2), x3), x4), x5), x6) in x1
+			.into_iter()
 			.zip(x2.into_iter())
 			.zip(x3.into_iter())
 			.zip(x4.into_iter())
@@ -178,8 +187,8 @@ impl PlotElement
 	}
 
 	pub fn new_plot_matrix<T: DataType, X: IntoIterator<Item = T>>(
-		plot_type: PlotType, is_3d: bool, mat: X, num_rows: usize, num_cols: usize, dimensions: Option<(f64, f64, f64, f64)>,
-		options: Vec<PlotOption<String>>,
+		plot_type: PlotType, is_3d: bool, mat: X, num_rows: usize, num_cols: usize,
+		dimensions: Option<(f64, f64, f64, f64)>, options: Vec<PlotOption<String>>,
 	) -> PlotElement
 	{
 		let mut count = 0;
@@ -264,7 +273,11 @@ impl PlotElement
 						write!(writer, ") ");
 						if self.num_cols > 1
 						{
-							write!(writer, "dx={:.12e} ", (x2 - x1) / (self.num_cols as f64 - 1.0));
+							write!(
+								writer,
+								"dx={:.12e} ",
+								(x2 - x1) / (self.num_cols as f64 - 1.0)
+							);
 						}
 						else
 						{
@@ -272,7 +285,11 @@ impl PlotElement
 						}
 						if self.num_rows > 1
 						{
-							write!(writer, "dy={:.12e} ", (y2 - y1) / (self.num_rows as f64 - 1.0));
+							write!(
+								writer,
+								"dy={:.12e} ",
+								(y2 - y1) / (self.num_rows as f64 - 1.0)
+							);
 						}
 						else
 						{
@@ -309,7 +326,7 @@ impl PlotElement
 				FillBetween =>
 				{
 					let mut found = false;
-					first_opt!{options,
+					first_opt! {options,
 						FillRegion(d) =>
 						{
 							found = true;
@@ -329,19 +346,40 @@ impl PlotElement
 				_ => (),
 			}
 
-			writer.write_str(" fill transparent solid ");
+			writer.write_str(" fill ");
 
-			first_opt!{self.options,
-				FillAlpha(a) =>
+			let mut is_pattern = false;
+			first_opt! {self.options,
+				FillPattern(pattern_opt) =>
 				{
-					write!(writer, "{:.12e}", a);
+					is_pattern = true;
+					writer.write_str("pattern ");
+					match pattern_opt
+					{
+						Fix(val) =>
+						{
+							write!(writer, "{}", val as i32);
+						}
+						_ => (),
+					}
+				}
+			}
+
+			if !is_pattern
+			{
+				writer.write_str("transparent solid ");
+				first_opt! {self.options,
+					FillAlpha(a) =>
+					{
+						write!(writer, "{:.12e}", a);
+					}
 				}
 			}
 
 			if self.plot_type.is_line()
 			{
 				writer.write_str(" border");
-				first_opt!{self.options,
+				first_opt! {self.options,
 					BorderColor(ref s) =>
 					{
 						write!(writer, r#" rgb "{}""#, s);
@@ -361,14 +399,14 @@ impl PlotElement
 
 		if self.plot_type.is_points()
 		{
-			first_opt!{self.options,
+			first_opt! {self.options,
 				PointSymbol(s) =>
 				{
 					write!(writer, " pt {}", char_to_symbol(s));
 				}
 			}
 
-			first_opt!{self.options,
+			first_opt! {self.options,
 				PointSize(z) =>
 				{
 					write!(writer, " ps {}", z);
@@ -379,7 +417,7 @@ impl PlotElement
 		AxesCommonData::write_color_options(writer, &self.options, None);
 
 		writer.write_str(" t \"");
-		first_opt!{self.options,
+		first_opt! {self.options,
 			Caption(ref s) =>
 			{
 				writer.write_str(&s);
@@ -387,7 +425,7 @@ impl PlotElement
 		}
 		writer.write_str("\"");
 
-		first_opt!{self.options,
+		first_opt! {self.options,
 			WhiskerBars(f) =>
 			{
 				write!(writer, " whiskerbars {}", f);
@@ -428,7 +466,9 @@ impl LabelType
 	}
 }
 
-pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<String>], writer: &mut Writer)
+pub fn write_out_label_options(
+	label_type: LabelType, options: &[LabelOption<String>], writer: &mut Writer,
+)
 {
 	let w = writer;
 	match label_type
@@ -440,28 +480,28 @@ pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<Str
 		_ => (),
 	}
 
-	first_opt!{options,
+	first_opt! {options,
 		TextOffset(x, y) =>
 		{
 			write!(w, " offset character {:.12e},{:.12e}", x, y);
 		}
 	}
 
-	first_opt!{options,
+	first_opt! {options,
 		TextColor(ref s) =>
 		{
 			write!(w, r#" tc rgb "{}""#, s);
 		}
 	}
 
-	first_opt!{options,
+	first_opt! {options,
 		Font(ref f, s) =>
 		{
 			write!(w, r#" font "{},{}""#, f, s);
 		}
 	}
 
-	first_opt!{options,
+	first_opt! {options,
 		Rotate(a) =>
 		{
 			write!(w, " rotate by {:.12e}", a);
@@ -471,7 +511,7 @@ pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<Str
 	if label_type.is_label()
 	{
 		let mut have_point = false;
-		first_opt!{options,
+		first_opt! {options,
 			MarkerSymbol(s) =>
 			{
 				write!(w, " point pt {}", char_to_symbol(s));
@@ -481,14 +521,14 @@ pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<Str
 
 		if have_point
 		{
-			first_opt!{options,
+			first_opt! {options,
 				MarkerColor(ref s) =>
 				{
 					write!(w, r#" lc rgb "{}""#, s);
 				}
 			}
 
-			first_opt!{options,
+			first_opt! {options,
 				MarkerSize(z) =>
 				{
 					write!(w, " ps {:.12e}", z);
@@ -496,7 +536,7 @@ pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<Str
 			}
 		}
 
-		first_opt!{options,
+		first_opt! {options,
 			TextAlign(a) =>
 			{
 				write!(w, "{}", match a
@@ -615,7 +655,7 @@ impl PlotType
 pub enum TickType
 {
 	None,
-	Custom(Vec<Tick<f64>>),
+	Custom(Vec<Tick<f64, String>>),
 	Auto(AutoOption<f64>, u32),
 }
 
@@ -829,7 +869,7 @@ impl AxisData
 
 			write_out_label_options(AxesTicks, &label_options[..], &mut *w);
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				OnAxis(b) =>
 				{
 					w.write_str(match b
@@ -840,7 +880,7 @@ impl AxisData
 				}
 			}
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				Mirror(b) =>
 				{
 					w.write_str(match b
@@ -851,7 +891,7 @@ impl AxisData
 				}
 			}
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				Inward(b) =>
 				{
 					w.write_str(match b
@@ -865,14 +905,14 @@ impl AxisData
 			let mut minor_scale = 0.5;
 			let mut major_scale = 0.5;
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				MinorScale(s) =>
 				{
 					minor_scale = s;
 				}
 			}
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				MajorScale(s) =>
 				{
 					major_scale = s;
@@ -881,7 +921,7 @@ impl AxisData
 
 			write!(w, " scale {:.12e},{:.12e}", major_scale, minor_scale);
 
-			first_opt!{tick_options,
+			first_opt! {tick_options,
 				Format(ref f) =>
 				{
 					write!(w, r#" format "{}""#, f);
@@ -891,8 +931,9 @@ impl AxisData
 		w.write_str("\n");
 	}
 
-	pub fn set_ticks_custom<T: DataType, TL: IntoIterator<Item = Tick<T>>>(
-		&mut self, ticks: TL, tick_options: Vec<TickOption<String>>, label_options: Vec<LabelOption<String>>,
+	pub fn set_ticks_custom<T: DataType, TL: IntoIterator<Item = Tick<T, String>>>(
+		&mut self, ticks: TL, tick_options: Vec<TickOption<String>>,
+		label_options: Vec<LabelOption<String>>,
 	)
 	{
 		self.tick_type = TickType::Custom(
@@ -910,8 +951,8 @@ impl AxisData
 	}
 
 	pub fn set_ticks(
-		&mut self, tick_placement: Option<(AutoOption<f64>, u32)>, tick_options: Vec<TickOption<String>>,
-		label_options: Vec<LabelOption<String>>,
+		&mut self, tick_placement: Option<(AutoOption<f64>, u32)>,
+		tick_options: Vec<TickOption<String>>, label_options: Vec<LabelOption<String>>,
 	)
 	{
 		if let Some((incr, mticks)) = tick_placement
@@ -1031,7 +1072,8 @@ impl AxesCommonData
 				c.write_str(axis.to_tick_str());
 				c.write_str(" ");
 				if self.x_axis.axis == *axis && self.x_axis.mgrid
-					|| self.y_axis.axis == *axis && self.y_axis.mgrid {
+					|| self.y_axis.axis == *axis && self.y_axis.mgrid
+				{
 					c.write_str(axis.to_mtick_str());
 					c.write_str(" ");
 				}
@@ -1055,11 +1097,13 @@ impl AxesCommonData
 		}
 	}
 
-	pub fn write_line_options(c: &mut Writer, options: &[PlotOption<String>], version: GnuplotVersion)
+	pub fn write_line_options(
+		c: &mut Writer, options: &[PlotOption<String>], version: GnuplotVersion,
+	)
 	{
 		let mut found = false;
 		c.write_str(" lw ");
-		first_opt!{options,
+		first_opt! {options,
 			LineWidth(w) =>
 			{
 				write!(c, "{:.12e}", w);
@@ -1073,7 +1117,7 @@ impl AxesCommonData
 
 		if version.major >= 5
 		{
-			first_opt!{options,
+			first_opt! {options,
 				LineStyle(d) =>
 				{
 					write!(c, " dt {}", d.to_int());
@@ -1082,7 +1126,7 @@ impl AxesCommonData
 		}
 		else
 		{
-			first_opt!{options,
+			first_opt! {options,
 				LineStyle(d) =>
 				{
 					write!(c, " lt {}", d.to_int());
@@ -1091,10 +1135,12 @@ impl AxesCommonData
 		}
 	}
 
-	pub fn write_color_options(c: &mut Writer, options: &[PlotOption<String>], default: Option<&str>)
+	pub fn write_color_options(
+		c: &mut Writer, options: &[PlotOption<String>], default: Option<&str>,
+	)
 	{
 		let mut col = default;
-		first_opt!{options,
+		first_opt! {options,
 			Color(ref s) =>
 			{
 				col = Some(&s)
@@ -1141,7 +1187,9 @@ impl AxesCommonData
 		}
 	}
 
-	pub fn set_label_common(&mut self, label_type: LabelType, text: &str, options: &[LabelOption<&str>])
+	pub fn set_label_common(
+		&mut self, label_type: LabelType, text: &str, options: &[LabelOption<&str>],
+	)
 	{
 		let c = &mut self.commands;
 
@@ -1206,7 +1254,12 @@ pub trait AxesCommon: AxesCommonPrivate
 	fn set_pos<'l>(&'l mut self, x: f64, y: f64) -> &'l mut Self
 	{
 		self.get_common_data_mut().grid_pos = None;
-		writeln!(&mut self.get_common_data_mut().commands, "set origin {:.12e},{:.12e}", x, y);
+		writeln!(
+			&mut self.get_common_data_mut().commands,
+			"set origin {:.12e},{:.12e}",
+			x,
+			y
+		);
 		self
 	}
 
@@ -1216,7 +1269,12 @@ pub trait AxesCommon: AxesCommonPrivate
 	/// * `h` - Height. Ranges from 0 to 1
 	fn set_size<'l>(&'l mut self, w: f64, h: f64) -> &'l mut Self
 	{
-		writeln!(&mut self.get_common_data_mut().commands, "set size {:.12e},{:.12e}", w, h);
+		writeln!(
+			&mut self.get_common_data_mut().commands,
+			"set size {:.12e},{:.12e}",
+			w,
+			h
+		);
 		self
 	}
 
@@ -1254,21 +1312,24 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `Align` - Specifies how to align the label
 	fn set_x_label<'l>(&'l mut self, text: &str, options: &[LabelOption<&str>]) -> &'l mut Self
 	{
-		self.get_common_data_mut().set_label_common(XLabel, text, options);
+		self.get_common_data_mut()
+			.set_label_common(XLabel, text, options);
 		self
 	}
 
 	/// Like `set_x_label`, but for the Y axis
 	fn set_y_label<'l>(&'l mut self, text: &str, options: &[LabelOption<&str>]) -> &'l mut Self
 	{
-		self.get_common_data_mut().set_label_common(YLabel, text, options);
+		self.get_common_data_mut()
+			.set_label_common(YLabel, text, options);
 		self
 	}
 
 	/// Like `set_x_label`, but for the color bar
 	fn set_cb_label<'l>(&'l mut self, text: &str, options: &[LabelOption<&str>]) -> &'l mut Self
 	{
-		self.get_common_data_mut().set_label_common(CBLabel, text, options);
+		self.get_common_data_mut()
+			.set_label_common(CBLabel, text, options);
 		self
 	}
 
@@ -1283,7 +1344,8 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `Align` - Specifies how to align the label
 	fn set_title<'l>(&'l mut self, text: &str, options: &[LabelOption<&str>]) -> &'l mut Self
 	{
-		self.get_common_data_mut().set_label_common(TitleLabel, text, options);
+		self.get_common_data_mut()
+			.set_label_common(TitleLabel, text, options);
 		self
 	}
 
@@ -1301,9 +1363,12 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `MarkerSymbol` - Specifies the symbol for the marker. Omit to hide the marker
 	///      * `MarkerSize` - Specifies the size for the marker
 	///      * `MarkerColor` - Specifies the color for the marker
-	fn label<'l>(&'l mut self, text: &str, x: Coordinate, y: Coordinate, options: &[LabelOption<&str>]) -> &'l mut Self
+	fn label<'l>(
+		&'l mut self, text: &str, x: Coordinate, y: Coordinate, options: &[LabelOption<&str>],
+	) -> &'l mut Self
 	{
-		self.get_common_data_mut().set_label_common(Label(x, y), text, options);
+		self.get_common_data_mut()
+			.set_label_common(Label(x, y), text, options);
 		self
 	}
 
@@ -1322,37 +1387,43 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `Rotate` - Specifies the rotation of the label
 	///      * `Align` - Specifies how to align the label
 	fn set_x_ticks<'l>(
-		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>, tick_options: &[TickOption<&str>],
-		label_options: &[LabelOption<&str>],
+		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>,
+		tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.x_axis
-			.set_ticks(tick_placement, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().x_axis.set_ticks(
+			tick_placement,
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
 	/// Like `set_x_ticks` but for the Y axis.
 	fn set_y_ticks<'l>(
-		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>, tick_options: &[TickOption<&str>],
-		label_options: &[LabelOption<&str>],
+		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>,
+		tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.y_axis
-			.set_ticks(tick_placement, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().y_axis.set_ticks(
+			tick_placement,
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
 	/// Like `set_x_ticks` but for the color bar axis.
 	fn set_cb_ticks<'l>(
-		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>, tick_options: &[TickOption<&str>],
-		label_options: &[LabelOption<&str>],
+		&'l mut self, tick_placement: Option<(AutoOption<f64>, u32)>,
+		tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.cb_axis
-			.set_ticks(tick_placement, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().cb_axis.set_ticks(
+			tick_placement,
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
@@ -1370,35 +1441,62 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `TextColor` - Specifies the color of the label
 	///      * `Rotate` - Specifies the rotation of the label
 	///      * `Align` - Specifies how to align the label
-	fn set_x_ticks_custom<'l, T: DataType, TL: IntoIterator<Item = Tick<T>>>(
-		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
+	fn set_x_ticks_custom<
+		'l,
+		T: DataType,
+		S: ToString,
+		TickT: Borrow<Tick<T, S>>,
+		TL: IntoIterator<Item = TickT>,
+	>(
+		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>],
+		label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.x_axis
-			.set_ticks_custom(ticks, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().x_axis.set_ticks_custom(
+			ticks.into_iter().map(|e| e.borrow().to_one_way_owned()),
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
 	/// Like `set_x_ticks_custom` but for the the Y axis.
-	fn set_y_ticks_custom<'l, T: DataType, TL: IntoIterator<Item = Tick<T>>>(
-		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
+	fn set_y_ticks_custom<
+		'l,
+		T: DataType,
+		S: ToString,
+		TickT: Borrow<Tick<T, S>>,
+		TL: IntoIterator<Item = TickT>,
+	>(
+		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>],
+		label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.y_axis
-			.set_ticks_custom(ticks, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().y_axis.set_ticks_custom(
+			ticks.into_iter().map(|e| e.borrow().to_one_way_owned()),
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
 	/// Like `set_x_ticks_custom` but for the the color bar axis.
-	fn set_cb_ticks_custom<'l, T: DataType, TL: IntoIterator<Item = Tick<T>>>(
-		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
+	fn set_cb_ticks_custom<
+		'l,
+		T: DataType,
+		S: ToString,
+		TickT: Borrow<Tick<T, S>>,
+		TL: IntoIterator<Item = TickT>,
+	>(
+		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>],
+		label_options: &[LabelOption<&str>],
 	) -> &'l mut Self
 	{
-		self.get_common_data_mut()
-			.cb_axis
-			.set_ticks_custom(ticks, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
+		self.get_common_data_mut().cb_axis.set_ticks_custom(
+			ticks.into_iter().map(|e| e.borrow().to_one_way_owned()),
+			tick_options.to_one_way_owned(),
+			label_options.to_one_way_owned(),
+		);
 		self
 	}
 
@@ -1541,7 +1639,8 @@ pub trait AxesCommon: AxesCommonPrivate
 	///      * `Color` - Specifies the color of the grid lines
 	///      * `LineStyle` - Specifies the style of the grid lines
 	///      * `LineWidth` - Specifies the width of the grid lines
-	fn set_grid_options<'l>(&'l mut self, front: bool, options: &[PlotOption<&str>]) -> &'l mut Self
+	fn set_grid_options<'l>(&'l mut self, front: bool, options: &[PlotOption<&str>])
+		-> &'l mut Self
 	{
 		self.get_common_data_mut().grid_front = front;
 		self.get_common_data_mut().grid_options = options.to_one_way_owned();
@@ -1669,7 +1768,9 @@ pub trait AxesCommon: AxesCommonPrivate
 	///
 	/// # Arguments
 	/// * `palette_generator` - The palette generator
-	fn set_custom_palette<T: IntoIterator<Item = (f32, f32, f32, f32)>>(&mut self, palette_generator: T) -> &mut Self
+	fn set_custom_palette<T: IntoIterator<Item = (f32, f32, f32, f32)>>(
+		&mut self, palette_generator: T,
+	) -> &mut Self
 	{
 		{
 			let c = &mut self.get_common_data_mut().commands as &mut Writer;
